@@ -1,7 +1,7 @@
 import logging
 
-from fileFormatter import FileFormatter
-from cmdParser import CmdParser
+from .fileFormatter import FileFormatter
+from .cmdParser import CmdParser
 import log
 
 
@@ -13,8 +13,6 @@ logger.debug(f'program started')
 def run():
     FileFormatter(CmdParser.parse_arguments()).run()
 
-run()
-
 
 logger.debug(f'program finished')
 
